@@ -22,6 +22,6 @@ print "ok 1\n";
 # (correspondingly "not ok 13") depending on the success of chunk 13
 # of the test code):
 
-my $REx = qr{((\d+)(?s).)(?<=1.)(\d*)(?(2)BAR)};
+my $REx = qr{[a-z-]+?};
 my $parser = YAPE::Regex::Explain->new($REx);
 print $parser->explain;
